#ifdef GL_ES
precision mediump float;
#endif

varying vec4 v_fragmentColor;
varying vec2 v_texCoord;
varying vec4 v_ttfData;

uniform sampler2D CC_Texture0;

uniform vec4  u_strokeColor;
uniform float u_strokeWidth;

uniform float u_grayContrast;

void main() {
	// First let's get our font color, same as the base distance field shader

	// Our alpha is the distance to the font border
	float fontDistance 		= texture2D(CC_Texture0, v_texCoord).a;
	// Let's find our pixel's alpha and antialias it when we're close to the border (when inside [0.5 - smoothing, O.5 + smoothing] range)
	float fontAlpha = smoothstep(0.5 - v_ttfData[0], 0.5 + v_ttfData[0], fontDistance);
	vec4 fontColor = vec4(v_fragmentColor.rgb, fontAlpha);
	
	// Now let's find our stroke color, same thing, but considering a farther border because of the stroke size, and a position offset

	// Our alpha is the distance to the "font + stroke size" border
	float strokeDistance 	= texture2D(CC_Texture0, v_texCoord + vec2(v_ttfData[2], v_ttfData[3])).a;
	float strokedBorder = 0.5 - v_ttfData[1]; // v_ttfData[1] is our stroke size
	// Let's find our pixel's stroke alpha and antialias it when we're close to the border (when inside [strokedBorder - smoothing, strokedBorder + smoothing] range)
	float strokeAlpha = smoothstep(strokedBorder - v_ttfData[0], strokedBorder + v_ttfData[0], strokeDistance) * u_strokeColor.a;
	vec4 strokeColor = vec4(u_strokeColor.rgb, strokeAlpha);

	// Now that we have both our font and stroke color values for this pixel, blend the 2 colors!
	vec4 result = mix(strokeColor, fontColor, fontAlpha);

	float gray = ((0.2 * result.r) + (0.7 * result.g) + (0.1 * result.b)) * u_grayContrast;
    gl_FragColor = vec4(gray, gray, gray, result.a * v_fragmentColor.a);
}

